@@ -46,7 +46,20 @@ extern sPreference Pref;
 extern Audio Sons;
 
 static char Points[]=". . . . . . . . . . . . . .";
-static struct mPy Menu_Py[10];
+static struct mPy Menu_Py[20];
+
+/*** Fait une attente pour 50fps ***/
+/***********************************/
+void Sleeping()
+{
+  int delay;
+
+  if( (Horloge-HorlogeAvant) < (1000/60) ) {
+    delay=1000/60-(Horloge-HorlogeAvant);
+    SDL_Delay(delay);
+    Horloge=SDL_GetTicks();
+  }
+}
 
 /*** Constructeur et Destructeur ***/
 /***********************************/
@@ -62,8 +75,6 @@ void AddBouton(int Num,e_Sprite NumSp,int X,int Y)
 {
   int NumS=(int)NumSp;
 
-  if(NumS>=(int)(T_level)) NumS=((int)(T_ENDTEXT)-(int)(T_level))*Pref.Langue+(int)(NumSp);
-  
   Menu_Py[Num].DepX=X-Sprites[NumS].Dim[0].L/2;
   Menu_Py[Num].DepY=Y-Sprites[NumS].Dim[0].H/2;
   Menu_Py[Num].FinX=X+Sprites[NumS].Dim[0].L/2;
@@ -91,8 +102,13 @@ void ChangeVideo(void)
   if(Pref.FullScreen)   vOption=SDL_SWSURFACE; // Bug acc aux bits pour les cordes
   else  vOption=SDL_SWSURFACE|SDL_DOUBLEBUF;
 #else
+#ifndef __AMIGAOS4__
   int vOption=SDL_SWSURFACE|SDL_DOUBLEBUF;
+#else
+  int vOption=SDL_SWSURFACE;
 #endif
+#endif
+
   if(Pref.FullScreen) vOption|=SDL_FULLSCREEN;
   sdlVideo=SDL_SetVideoMode(800,600,sdlVideoInfo->vfmt->BitsPerPixel,vOption);
   if(sdlVideo==NULL) {
@@ -201,6 +217,7 @@ eMenu Menu::SDLMain(void)
     // Gre les variables
     HorlogeAvant=Horloge;
     Horloge=SDL_GetTicks();
+    Sleeping();
     
     // Gre l'Affichage
     Ec[NumEc].Efface(fmenu);
@@ -225,38 +242,31 @@ eMenu Menu::SDLMain_Langue(void)
   int Ecart;
   int i;
   int x,y;
-  int MemoL=Pref.Langue;
+  int OldLangue=Pref.Langue;
 
   // Initialisations Divers
   Sourie.Init(Menu_Py); // Initialise la sourie
-  PyE=MemoL;
+  PyE=Pref.Langue;
   if(PyE==-1) PyE=1;
 
   // Prend l'image du fond et fait l'affichage 
   Sprites[fond_menu].Affiche(400,300,0,Sprites[fmenu].Image[0]);
-
+  
   // Affiche les langues possibles
-  if(Pref.NLangues>4) NCol=2;
+  NCol=3;
   if(Pref.NLangues%NCol==0) NL=Pref.NLangues/NCol;
   else NL=Pref.NLangues/NCol+1;
   Ecart=600/(NL+1);
 
   for(i=0;i<Pref.NLangues;i++) {
-    if(NCol>1) {
-      if(i<NL) x=220;
-      else x=580;
-    }
-    else x=400;
-
-      y=(i%NL)*Ecart+Ecart;
-
-    Pref.Langue=i;
-    AfficheText(x,y,T_Langue,Sprites[fmenu].Image[0]);
-    AddBouton(i,T_Langue,x,y);
+    x=(i/NL)*(800/3)+(800/6);
+    y=(i%NL)*Ecart+Ecart;
+    
+    Sprites[T_Langue+i].Affiche(x,y,0,Sprites[fmenu].Image[0]);
+    AddBouton(i,(e_Sprite)(T_Langue+i),x,y);
   }
   
   Menu_Py[Pref.NLangues].DepX=-1;
-  Pref.Langue=MemoL;
 
   // Efface le fond
   NumEc=0;
@@ -306,6 +316,7 @@ eMenu Menu::SDLMain_Langue(void)
 	  case SDLK_RETURN:
 	  case SDLK_KP_ENTER:
 	    Pref.Langue=PyE;
+	    if(Pref.Langue!=OldLangue) LoadLangue();
 	    return mMenu;
 	  }
 	}
@@ -319,18 +330,15 @@ eMenu Menu::SDLMain_Langue(void)
     // Gre les variables
     HorlogeAvant=Horloge;
     Horloge=SDL_GetTicks();
+    Sleeping();
     
     // Gre l'Affichage
     Ec[NumEc].Efface(fmenu);
 
-    if(NCol>1) {
-      if(PyE<NL) Affiche_Main(220);
-      else Affiche_Main(580);
-    }
-    else Affiche_Main();
+    Affiche_Main_Centre();
 
     Sourie.Affiche(NumEc);
-    
+
     // Echange les buffets video
     SDL_Flip(sdlVideo);
     NumEc=(NumEc+1)&1;
@@ -344,8 +352,6 @@ eMenu Menu::SDLMain_Langue(void)
 /***************************************/
 void Menu::InitMain_Options(void)
 {
-  int NumS;
-
   // Initialisations Divers
   Sourie.Init(Menu_Py); // Initialise la sourie
   PyE=4;
@@ -367,11 +373,10 @@ void Menu::InitMain_Options(void)
   AddBouton(3,monde,180,400);
 
   // Centre  gauche le text de menu
-  NumS=((int)(T_ENDTEXT)-(int)(T_level))*Pref.Langue+(int)(T_menu);
-  CentreM=120+Sprites[NumS].Dim[0].L/2;
+  CentreM=120+Sprites[T_menu].Dim[0].L/2;
   AfficheText(CentreM,490,T_menu,Sprites[fmenu].Image[0]);
   AddBouton(4,T_menu,CentreM,490);
-  
+
   // Boutons des bruitages
   Sprites[fleches].Affiche(250,110,1,Sprites[fmenu].Image[0]);
   Sprites[fleches].Affiche(700,110,4,Sprites[fmenu].Image[0]);
@@ -564,6 +569,7 @@ eMenu Menu::SDLMain_Options(void)
     // Gre les variables
     HorlogeAvant=Horloge;
     Horloge=SDL_GetTicks();
+    Sleeping();
     
     // Gre l'Affichage
     Ec[NumEc].Efface(fmenu);
@@ -724,6 +730,7 @@ eMenu Menu::SDLMain_Speed(void)
     // Gre les variables
     HorlogeAvant=Horloge;
     Horloge=SDL_GetTicks();
+    Sleeping();
     
     // Gre l'Affichage
     Ec[NumEc].Efface(fmenu);
@@ -844,6 +851,7 @@ eMenu Menu::SDLMain_Niveau(void)
     // Gre les variables
     HorlogeAvant=Horloge;
     Horloge=SDL_GetTicks();
+    Sleeping();
     
     // Gre l'Affichage
     Ec[NumEc].Efface(fmenu);
@@ -1003,6 +1011,7 @@ eMenu Menu::SDLMain_HR(void)
     // Gre les variables
     HorlogeAvant=Horloge;
     Horloge=SDL_GetTicks();
+    Sleeping();
     
     // Gre l'Affichage
     Ec[NumEc].Efface(fmenu);
@@ -1138,6 +1147,7 @@ eMenu Menu::SDLMain_InGame(void)
     // Gre les variables
     HorlogeAvant=Horloge;
     Horloge=SDL_GetTicks();
+    Sleeping();
     
     // Gre l'Affichage
     Ec[NumEc].Efface(fmenu);
@@ -1272,6 +1282,7 @@ eMenu Menu::SDLMain_Score(bool EditScore)
     // Gre les variables
     HorlogeAvant=Horloge;
     Horloge=SDL_GetTicks();
+    Sleeping();
     
     // Gre l'Affichage
     Ec[NumEc].Efface(fmenu);
@@ -1308,3 +1319,16 @@ void Menu::Affiche_Main(int Centre)
   Ec[NumEc].Affiche(fleche_gauche,NumSp,x1,y);
   Ec[NumEc].Affiche(fleche_droite,NumSp,x2,y);
 }
+
+/*** Centre les flches sur le boutton ***/
+/*****************************************/
+void Menu::Affiche_Main_Centre()
+{
+  int NumSp=(Horloge/50)%20;
+  int x1=Menu_Py[PyE].DepX-5;
+  int x2=Menu_Py[PyE].FinX+5;
+  int y=(Menu_Py[PyE].FinY+Menu_Py[PyE].DepY)/2;
+  
+  Ec[NumEc].Affiche(fleche_gauche,NumSp,x1,y);
+  Ec[NumEc].Affiche(fleche_droite,NumSp,x2,y);
+}
